@@ -1,4 +1,4 @@
-# $Id: AMAVIS.pm,v 1.64 2003/12/11 03:11:56 bengen Exp $
+# $Id: AMAVIS.pm,v 1.66 2004/07/27 13:42:45 braeucup Exp $
 
 #
 # AMAVIS main module
@@ -21,7 +21,7 @@
 package AMAVIS;
 use strict;
 use vars qw($VERSION);
-$VERSION='0.1.6.6';
+$VERSION='0.1.6.7';
 
 require Exporter;
 @AMAVIS::ISA = qw(Exporter);
@@ -292,7 +292,7 @@ sub init {
     };
   }
 
-  @notifiers=split / *, */,$cfg->val('global','notifiers');
+  @notifiers = split (/ *, */, ($cfg->val('global','notifiers') || ''));
   unless (defined $notifiers[0]) {
     shift @notifiers;
   }
