@@ -1,8 +1,11 @@
-# $Id: Panda.pm,v 1.5 2004/07/28 13:46:40 braeucup Exp $
+# $Id: Panda.pm,v 1.6 2004/08/23 13:20:46 braeucup Exp $
 
 #
 # Support module for Panda Antivirus
 #
+# HISTORY
+# 08/23/2004 Logging and output fixes from Gerald Schwarzecker
+#            <gerald@schwarzecker.homelinux.net>.
 
 package AMAVIS::AV::Panda;
 use strict;
@@ -65,16 +68,16 @@ sub scan {
     s/^\s*(.*)\s*$/\1/g;
     push @output, $_;
     writelog($args, LOG_DEBUG, $_);
-    if (/Number of files infected\.+:\s*(\d+)/) {
+    if (/Number of files infected\s\.+:\s*(\d+)/) {
       $numvirus = $1;
-      writelog($args, LOG_DEBUG, "GOT NUMBER: $numvirus");
+      writelog($args, LOG_DEBUG, "GOT NUMBER of the infected files ...: $numvirus");
     }
   }
   writelog($args, LOG_DEBUG, "End output from $cfg_panda_binary\n");
   wait;
   my $errval = ($? >> 8);
   writelog($args, LOG_DEBUG,"Return code $errval");
-  if ($errval == 0) {
+  if ($errval != 0) {
     if($numvirus > 0) {
       writelog($args, LOG_DEBUG, "Number of viruses found: $numvirus");
       my %uniq;
@@ -93,7 +96,7 @@ sub scan {
   else {
     writelog($args,LOG_ERR,
 	     "Virus scanner failure: FIXME Some reason.");
-    return 0;
+    return 1;
   }
   return 1;
 }
