@@ -1,4 +1,4 @@
-# $Id: Exim.pm,v 1.21 2004/07/27 12:48:38 braeucup Exp $
+# $Id: Exim.pm,v 1.23 2005/01/14 18:30:03 braeucup Exp $
 
 #
 # MTA module for "regular" Exim setup
@@ -29,8 +29,8 @@ use vars qw(
 sub init {
   my $self = shift;
   my $args = shift;
-  $cfg_exim_binary = (($AMAVIS::cfg->val('Exim', 'exim') =~ s/[^\w]//g) || '/usr/sbin/exim');
-  $cfg_exim_args = (($AMAVIS::cfg->val('Exim', 'args') =~ s/[^\w]//g) || '-oMr no-scan -i -f');
+  $cfg_exim_binary = ($AMAVIS::cfg->val('Exim', 'exim') || '/usr/sbin/exim');
+  $cfg_exim_args = ($AMAVIS::cfg->val('Exim', 'args') || '-oMr no-scan -i -f');
 
   if (! -x $cfg_exim_binary) {
     writelog($args,LOG_CRIT, "$cfg_exim_binary not executable");
@@ -79,6 +79,7 @@ sub get_directory {
   $$args{'message_id'}=$message_id;
   my $directory = $prefix.$message_id;
   mkdir "$directory/parts", 0777;
+  $$args{'directory'} = $directory;
 
   # Open message file that is later going to be disected and scanned
   my $output = IO::File->new("+>$directory/email.txt");
@@ -126,7 +127,6 @@ sub get_directory {
   # the record.
   $output->seek(0,0);
   $$args{'filehandle'} = $output;
-  $$args{'directory'} = $directory;
 
   # Return successfully
   return 1;
