@@ -1,4 +1,4 @@
-# $Id: SMTP.pm,v 1.25 2003/12/11 03:11:56 bengen Exp $
+# $Id: SMTP.pm,v 1.32 2004/07/27 13:32:52 braeucup Exp $
 
 #
 # MTA module for pure SMTP setup
@@ -72,7 +72,8 @@ sub init {
   }
 
   $cfg_daemon = ($AMAVIS::cfg->val('SMTP', 'daemon') or 'yes');
-  $cfg_pidfile = $AMAVIS::cfg->val('SMTP', 'pidfile');
+  $cfg_pidfile = $AMAVIS::cfg->val('SMTP', 'pidfile')
+	  || '/var/run/amavis-ng/amavisd.pid';
 
   # Session timeout:
   # undef: accept message immediately
@@ -164,7 +165,7 @@ sub init {
   my $pidfile=IO::File->new(">$cfg_pidfile");
   unless (defined $pidfile) {
     writelog($args,LOG_ERR, __PACKAGE__.
-	     ": Unable to create PID file: $!");
+	     ": Unable to create PID file $cfg_pidfile: $!");
     return 0;
   }
   else {
@@ -175,7 +176,7 @@ sub init {
   }
   $0='amavisd';
 
-  if ($AMAVIS::cfg->val('global', 'x-header') eq 'true') {
+  if (($AMAVIS::cfg->val('global', 'x-header') || '') eq 'true') {
     $cfg_x_header = 1
   };
   $cfg_x_header_tag = $AMAVIS::cfg->val('global', 'x-header-tag');
@@ -308,6 +309,13 @@ sub accept_message( $ ) {
 
   my $result;
 
+  if ( $#{$$args{'recipients'}} < 0) {
+    writelog($args, LOG_INFO, __PACKAGE__.
+	     ": Back connection SMTP server did not accept any of our recipients. Not sending message.");
+    $smtpclient->quit;
+    return 1;
+  }
+
   writelog($args,LOG_DEBUG, "Sending DATA");
   $result=$smtpclient->data();
   return 0 unless ($result);
@@ -415,7 +423,7 @@ sub freeze_message( $ ) {
     }
     else {
       writelog($args,LOG_ERR,__PACKAGE__.
-	       ": Coultn't do anything else.");
+	       ": Couldn't do anything else.");
       return 0;
     }
   }
@@ -513,20 +521,26 @@ sub handle_smtp_connection {
 	$from = p_addr($1);
 	@to=();
 
-	writelog($args,LOG_DEBUG, "Setting sender: $$args{'sender'}");
-	$result=$smtpclient->mail($$args{'sender'});
+	writelog($args,LOG_DEBUG, "Setting sender: $from");
+	$result=$smtpclient->mail($from);
 	if ($result) {
 	  $conn->print("250 Ok.\r\n");
 	} else {
-	  $conn->print("500 Back connection did not accept SENDER.\r\n");
+	  $conn->print("500 Back connection did not accept $from as sender.\r\n");
 	  $from=undef;
 	}
 	next;
       };
       /^RCPT TO:(.*)$/i && do {
 	if (defined $from) {
-	  push @to, p_addr($1);
-	  $conn->print("250 Ok.\r\n");
+	  $result=$smtpclient->recipient(p_addr($1));
+	  if ($result) {
+	    push @to, p_addr($1);
+	    $conn->print("250 Ok.\r\n");
+	  }
+	  else {
+	    $conn->print("503 Back connection refused recipient.\r\n");
+	  }
 	}
 	else {
 	  $conn->print("503 Who are you?\r\n");
