@@ -1,4 +1,4 @@
-# $Id: SMTP2.pm,v 1.1 2003/11/26 10:23:11 bengen Exp $
+# $Id: SMTP2.pm,v 1.2 2004/07/27 12:48:38 braeucup Exp $
 
 #
 # MTA module for pure SMTP setup
@@ -175,7 +175,7 @@ sub init {
   }
   $0='amavisd';
 
-  if ($AMAVIS::cfg->val('global', 'x-header') eq 'true') {
+  if (($AMAVIS::cfg->val('global', 'x-header') || '') eq 'true') {
     $cfg_x_header = 1
   };
   $cfg_x_header_tag = $AMAVIS::cfg->val('global', 'x-header-tag');
